==> haskell-microspec-0.2.1.3-317-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-microspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microspec
version:              0.2.1.3
visibility:           public
id:                   microspec-0.2.1.3-8YB9Bcjrgb38DTQlNS60Eq
key:                  microspec-0.2.1.3-8YB9Bcjrgb38DTQlNS60Eq
license:              BSD-3-Clause
maintainer:           Tom Murphy
author:               Tom Murphy
stability:            experimental
synopsis:             Tiny QuickCheck test library with minimal dependencies
description:
    A tiny (1 module, <500 lines) property-based (and unit) testing library with minimal dependencies.

    Instead of reinventing the wheel (<https://xkcd.com/927>), we use a
    RSpec/HSpec-like DSL and run tests with QuickCheck.

    For many use-cases, microspec is a drop-in replacement for hspec.

    > import Test.Microspec
    >
    > main :: IO ()
    > main = microspec $ do
    >    describe "replicate" $ do
    >       it "doubles with 2" $
    >          replicate 2 '\''x'\'' === "xx"
    >       it "creates a list of the right size" $
    >          \(Positive n) -> length (replicate n '\''x'\'') === n
    >
    >    describe "reverse" $ do
    >       it "reverse . reverse === id" $ \l ->
    >          reverse (reverse l) === (l :: [Int])
    >
    >    describe "tail" $
    >       it "length is -1" $ \(NonEmpty l) ->
    >          length (tail l :: [Int]) === length l - 1
    >
    >    describe "solve the halting problem" $
    >       pending

category:             Test, Testing
abi:                  d06b8213434b51c7cad04bba2e86ce6c
exposed:              True
exposed-modules:      Test.Microspec
import-dirs:          /usr/lib/ghc-9.6.6/site-local/microspec-0.2.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/microspec-0.2.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/microspec-0.2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microspec
hs-libraries:         HSmicrospec-0.2.1.3-8YB9Bcjrgb38DTQlNS60Eq
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1
    time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-microspec/html/microspec.haddock
haddock-html:         /usr/share/doc/haskell-microspec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microspec-0.2.1.3-318-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-microspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microspec
version:              0.2.1.3
visibility:           public
id:                   microspec-0.2.1.3-6fIi2E7WLBdK5Wx3v1DTx8
key:                  microspec-0.2.1.3-6fIi2E7WLBdK5Wx3v1DTx8
license:              BSD-3-Clause
maintainer:           Tom Murphy
author:               Tom Murphy
stability:            experimental
synopsis:             Tiny QuickCheck test library with minimal dependencies
description:
    A tiny (1 module, <500 lines) property-based (and unit) testing library with minimal dependencies.

    Instead of reinventing the wheel (<https://xkcd.com/927>), we use a
    RSpec/HSpec-like DSL and run tests with QuickCheck.

    For many use-cases, microspec is a drop-in replacement for hspec.

    > import Test.Microspec
    >
    > main :: IO ()
    > main = microspec $ do
    >    describe "replicate" $ do
    >       it "doubles with 2" $
    >          replicate 2 '\''x'\'' === "xx"
    >       it "creates a list of the right size" $
    >          \(Positive n) -> length (replicate n '\''x'\'') === n
    >
    >    describe "reverse" $ do
    >       it "reverse . reverse === id" $ \l ->
    >          reverse (reverse l) === (l :: [Int])
    >
    >    describe "tail" $
    >       it "length is -1" $ \(NonEmpty l) ->
    >          length (tail l :: [Int]) === length l - 1
    >
    >    describe "solve the halting problem" $
    >       pending

category:             Test, Testing
abi:                  5dd89554e8fcc9577a3931e442f97239
exposed:              True
exposed-modules:      Test.Microspec
import-dirs:          /usr/lib/ghc-9.6.6/site-local/microspec-0.2.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/microspec-0.2.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/microspec-0.2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microspec
hs-libraries:         HSmicrospec-0.2.1.3-6fIi2E7WLBdK5Wx3v1DTx8
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-microspec/html/microspec.haddock
haddock-html:         /usr/share/doc/haskell-microspec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
